/*
 * Copyright © 2014 Igalia S.L.
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 */

#ifndef WL_WEBKITGTK_CLIENT_PROTOCOL_H
#define WL_WEBKITGTK_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct wl_surface;
struct wl_webkitgtk;

extern const struct wl_interface wl_webkitgtk_interface;

#define WL_WEBKITGTK_SET_SURFACE_FOR_WIDGET	0

#define WL_WEBKITGTK_SET_SURFACE_FOR_WIDGET_SINCE_VERSION	1

static inline void
wl_webkitgtk_set_user_data(struct wl_webkitgtk *wl_webkitgtk, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) wl_webkitgtk, user_data);
}

static inline void *
wl_webkitgtk_get_user_data(struct wl_webkitgtk *wl_webkitgtk)
{
	return wl_proxy_get_user_data((struct wl_proxy *) wl_webkitgtk);
}

static inline uint32_t
wl_webkitgtk_get_version(struct wl_webkitgtk *wl_webkitgtk)
{
	return wl_proxy_get_version((struct wl_proxy *) wl_webkitgtk);
}

static inline void
wl_webkitgtk_destroy(struct wl_webkitgtk *wl_webkitgtk)
{
	wl_proxy_destroy((struct wl_proxy *) wl_webkitgtk);
}

static inline void
wl_webkitgtk_set_surface_for_widget(struct wl_webkitgtk *wl_webkitgtk, struct wl_surface *surface, uint32_t id)
{
	wl_proxy_marshal((struct wl_proxy *) wl_webkitgtk,
			 WL_WEBKITGTK_SET_SURFACE_FOR_WIDGET, surface, id);
}

#ifdef  __cplusplus
}
#endif

#endif
